Block

Struct Block 

pub struct Block { /* private fields */ }
Componente genérico que representa un bloque de contenido.

Los bloques se utilizan como contenedores de otros componentes o contenidos, con un título opcional y un cuerpo que sólo se renderiza si existen componentes hijos (children).

Implementations

Source

impl Block

pub const fn classes(&self) -> &Classes

Devuelve las clases CSS asociadas al bloque.

pub const fn title(&self) -> &L10n

Devuelve el título del bloque.

pub const fn children(&self) -> &Children

Devuelve la lista de componentes hijo del bloque.

Source

impl Block

pub fn with_id(self, id: impl AsRef<str>) -> Self

Establece el identificador único (id) del bloque.

También añade el método alter_id() generado por #[builder_fn]

Permite modificar la instancia (&mut self) con los mismos argumentos pero sin consumirla.

pub fn alter_id(&mut self, ...) -> &mut Self
pub fn with_classes(self, op: ClassesOp, classes: impl AsRef<str>) -> Self

Modifica la lista de clases CSS aplicadas al bloque.

También añade el método alter_classes() generado por #[builder_fn]

Permite modificar la instancia (&mut self) con los mismos argumentos pero sin consumirla.

pub fn alter_classes(&mut self, ...) -> &mut Self
pub fn with_title(self, title: L10n) -> Self

Establece el título del bloque.

También añade el método alter_title() generado por #[builder_fn]

Permite modificar la instancia (&mut self) con los mismos argumentos pero sin consumirla.

pub fn alter_title(&mut self, ...) -> &mut Self
pub fn with_child(self, op: impl Into<ChildOp>) -> Self

Añade un nuevo componente al bloque o modifica la lista de componentes (children) con una operación ChildOp.

También añade el método alter_child() generado por #[builder_fn]

Permite modificar la instancia (&mut self) con los mismos argumentos pero sin consumirla.

pub fn alter_child(&mut self, ...) -> &mut Self